<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Zobrazit upozornění v prohlížeči při příchozí zprávě';
$labels['desktop'] = 'Zobrazit upozornění na ploše při příchozí zprávě';
$labels['sound'] = 'Přehrát zvuk při příchozí zprávě';
$labels['test'] = 'Vyzkoušet';
$labels['title'] = 'Nová zpráva!';
$labels['body'] = 'Dostali jste novou zprávu.';
$labels['testbody'] = 'Toto je zkouška upozornění.';
$labels['desktopdisabled'] = 'Upozornění na ploše jsou ve vašem prohlížeči vypnuté.';
$labels['desktopunsupported'] = 'Váš prohlížeč nepodporuje upozornění na ploše.';
$labels['desktoptimeout'] = 'Zavřít upozornění na ploše';
