<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['encryption'] = 'Kryptering';
$labels['keyname'] = 'Navn';
$labels['keyid'] = 'Nøkkel ID';
$labels['typeencrypt'] = 'Krypter';
$labels['subkeyid'] = 'ID';
$labels['subkeycreated'] = 'Opprettet';
$labels['expiresnever'] = 'Aldri';
$labels['unknown'] = 'ukjent';
$labels['userid'] = 'ID';
$labels['createkeys'] = 'Lag et nytt nøkkelpar';
$labels['keychpass'] = 'Bytt passord';
$labels['newkeypass'] = 'Passord';
$labels['keyimportlabel'] = 'Importer fra fil';
