<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Userinfo plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['userinfo'] = '사용자 정보';
$labels['infoforuser'] = '$user 정보';
$labels['created'] = '생성 날짜';
$labels['lastlogin'] = '마지막 로그인 날짜';
$labels['defaultidentity'] = '기본 신원';
$labels['userid'] = 'ID';
