<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'يېڭى ئۇچۇر كەلگەندە تور كۆرگۈچ ئۇقتۇرۇشىنى كۆرسىتىش';
$labels['desktop'] = 'يېڭى خەت كەلگەندە ئۈستەل يۈزى ئۇقتۇرۇشىنى كۆرسىتىش';
$labels['sound'] = 'يېڭى ئۇچۇر كەلگەندە ئاۋاز چىقىرىش';
$labels['test'] = 'سىناق';
$labels['title'] = 'يېڭى خەت!';
$labels['body'] = 'سىزگە بىر يېڭى خەت كەلدى.';
$labels['testbody'] = 'بۇ بولسا سىناق ئۇقتۇرۇش.';
$labels['desktopdisabled'] = 'ئۈستەل يۈزى ئۇقتۇرۇشى سىزنىڭ تور كۆگۈچىڭىزدە ئىتىك.';
$labels['desktopunsupported'] = 'سىزنىڭ تور كۆرگۈچىڭىز ئۈستەل يۈزى ئۇقتۇرۇشىنى قوللىمايدۇ.';
$labels['desktoptimeout'] = 'ئۈستەل يۈزى ئۇقتۇرۇشىنى تاقاش';
