<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archiwum';
$labels['buttontitle'] = 'Przenieś do archiwum';
$labels['archived'] = 'Pomyślnie zarchiwizowano';
$labels['archivedreload'] = 'Pomyślnie zarchiwizowano. Odśwież stronę aby zobaczyć nowe foldery.';
$labels['archiveerror'] = 'Nie można zarchiwizować niektórych wiadomości';
$labels['archivefolder'] = 'Archiwum';
$labels['settingstitle'] = 'Archiwum';
$labels['archivetype'] = 'Podziel archiwum wg';
$labels['archivetypeyear'] = 'Roku (np. Archiwum/2012)';
$labels['archivetypemonth'] = 'Miesiąca (np. Archiwum/2012/06)';
$labels['archivetypetbmonth'] = 'Miesiąca - Kompatybilnie z Thunderbird (np. Archive/2012/2012-06)';
$labels['archivetypefolder'] = 'Oryginalny folder';
$labels['archivetypefolderyear'] = 'Rok i folder wiadomości (np. Archive/2012/...)';
$labels['archivetypefoldermonth'] = 'Rok, miesiąc i folder wiadomości (np. Archive/2012/06/...)';
$labels['archivetypesender'] = 'E-mail nadawcy';
$labels['unkownsender'] = 'nieznany';
$labels['readonarchive'] = 'Podczas archiwizowania oznacz wiadomość jako przeczytaną';
